@@ -1,8 +1,7 @@
-# -*- coding: utf-8 -*-
 #
 # MIT License
 #
-# Copyright (c) 2018 Franck Nijhof
+# Copyright (c) 2018-2020 Franck Nijhof
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -25,5 +24,5 @@
 """Repository Updater bootstrap."""
 from . import cli
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     cli.repository_updater(None, None, None, None)
