@@ -1,8 +1,7 @@
-# -*- coding: utf-8 -*-
 #
 # MIT License
 #
-# Copyright (c) 2018 Franck Nijhof
+# Copyright (c) 2018-2020 Franck Nijhof
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -24,7 +23,7 @@
 
 """Constants used by the Repository Updater program."""
 
-CHANNEL_STABLE = 'stable'
-CHANNEL_BETA = 'beta'
-CHANNEL_EDGE = 'edge'
+CHANNEL_STABLE = "stable"
+CHANNEL_BETA = "beta"
+CHANNEL_EDGE = "edge"
 CHANNELS = [CHANNEL_STABLE, CHANNEL_BETA, CHANNEL_EDGE]
